Comment cleanup, semantic types, information hiding.
[open-adventure.git] / score.c
diff --git a/score.c b/score.c
index abe333705ebde9615663d03de945eb60f1de43f0..9b3f8f3ea17ee71a1ecd05daf93d28896463fef0 100644 (file)
--- a/score.c
+++ b/score.c
@@ -1,19 +1,18 @@
 #include <stdlib.h>
 #include "advent.h"
-#include "database.h"
-#include "newdb.h"
+#include "dungeon.h"
 
 /*
  * scoring and wrap-up
  */
 
-static long mxscor;    /* ugh..the price for having score() not exit. */
+static int mxscor;     /* ugh..the price for having score() not exit. */
 
 long score(enum termination mode)
 /* mode is 'scoregame' if scoring, 'quitgame' if quitting, 'endgame' if died
  * or won */
 {
-    long score = 0;
+    int score = 0;
 
     /*  The present scoring algorithm is as follows:
      *     Objective:          Points:        Present total possible:
@@ -37,48 +36,54 @@ long score(enum termination mode)
     /*  First tally up the treasures.  Must be in building and not broken.
      *  Give the poor guy 2 points just for finding each treasure. */
     mxscor = 0;
-    for (long i = MINTRS; i <= MAXTRS; i++) {
-        if (object_descriptions[i].inventory != 0) {
-            long k = 12;
-            if (i == CHEST)k = 14;
-            if (i > CHEST)k = 16;
-            if (game.prop[i] >= 0)
+    for (int i = 1; i <= NOBJECTS; i++) {
+        if (!objects[i].is_treasure)
+            continue;
+        if (objects[i].inventory != 0) {
+            int k = 12;
+            if (i == CHEST)
+                k = 14;
+            if (i > CHEST)
+                k = 16;
+            if (game.prop[i] > STATE_NOTFOUND)
                 score += 2;
-            if (game.place[i] == LOC_BUILDING && game.prop[i] == 0)
+            if (game.place[i] == LOC_BUILDING && game.prop[i] == STATE_FOUND)
                 score += k - 2;
             mxscor += k;
         }
     }
 
/*  Now look at how he finished and how far he got.  MAXDIE and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still
      *  indicates whether he reached the endgame.  And if he got as far as
      *  "cave closed" (indicated by "game.closed"), then bonus is zero for
      *  mundane exits or 133, 134, 135 if he blew it (so to speak). */
-    score += (MAXDIE - game.numdie) * 10;
-    mxscor += MAXDIE * 10;
+    score += (NDEATHS - game.numdie) * 10;
+    mxscor += NDEATHS * 10;
     if (mode == endgame)
         score += 4;
     mxscor += 4;
-    if (game.dflag != 0)score += 25;
+    if (game.dflag != 0)
+        score += 25;
     mxscor += 25;
-    if (game.closng)score += 25;
+    if (game.closng)
+        score += 25;
     mxscor += 25;
     if (game.closed) {
-        if (game.bonus == 0)
+        if (game.bonus == none)
             score += 10;
-        if (game.bonus == SPLATTER_MESSAGE)
+        if (game.bonus == splatter)
             score += 25;
-        if (game.bonus == DEFEAT_MESSAGE)
+        if (game.bonus == defeat)
             score += 30;
-        if (game.bonus == VICTORY_MESSAGE)
+        if (game.bonus == victory)
             score += 45;
     }
     mxscor += 45;
 
     /* Did he come to Witt's End as he should? */
-    if (game.place[MAGZIN] == LOC_WITTSEND)
+    if (game.place[MAGAZINE] == LOC_WITTSEND)
         score += 1;
     mxscor += 1;
 
@@ -87,9 +92,9 @@ long score(enum termination mode)
     mxscor += 2;
 
     /* Deduct for hints/turns/saves. Hints < 4 are special; see database desc. */
-    for (long i = 1; i <= HNTMAX; i++) {
+    for (int i = 0; i < NHINTS; i++) {
         if (game.hinted[i])
-            score = score - HINTS[i][2];
+            score = score - hints[i].penalty;
     }
     if (game.novice)
         score -= 5;
@@ -99,9 +104,7 @@ long score(enum termination mode)
 
     /* Return to score command if that's where we came from. */
     if (mode == scoregame) {
-        SETPRM(1, score, mxscor);
-        SETPRM(3, game.turns, game.turns);
-        RSPEAK(GARNERED_POINTS);
+        rspeak(GARNERED_POINTS, score, mxscor, game.turns, game.turns);
     }
 
     return score;
@@ -113,24 +116,21 @@ void terminate(enum termination mode)
     long points = score(mode);
 
     if (points + game.trnluz + 1 >= mxscor && game.trnluz != 0)
-        RSPEAK(TOOK_LONG);
+        rspeak(TOOK_LONG);
     if (points + game.saved + 1 >= mxscor && game.saved != 0)
-        RSPEAK(WITHOUT_SUSPENDS);
-    SETPRM(1, points, mxscor);
-    SETPRM(3, game.turns, game.turns);
-    RSPEAK(TOTAL_SCORE);
-    for (long i = 1; i <= (long)CLSSES; i++) {
-        if (CVAL[i] >= points) {
-            newspeak(class_messages[i]);
-            i = CVAL[i] + 1 - points;
-            SETPRM(1, i, i);
-            RSPEAK(NEXT_HIGHER);
-            exit(0);
+        rspeak(WITHOUT_SUSPENDS);
+    rspeak(TOTAL_SCORE, points, mxscor, game.turns, game.turns);
+    for (int i = 1; i <= (long)NCLASSES; i++) {
+        if (classes[i].threshold >= points) {
+            speak(classes[i].message);
+            i = classes[i].threshold + 1 - points;
+            rspeak(NEXT_HIGHER, i, i);
+            exit(EXIT_SUCCESS);
         }
     }
-    RSPEAK(OFF_SCALE);
-    RSPEAK(NO_HIGHER);
-    exit(0);
+    rspeak(OFF_SCALE);
+    rspeak(NO_HIGHER);
+    exit(EXIT_SUCCESS);
 }
 
 /* end */
@@ -37,48 +36,54 @@ long score(enum termination mode)
     }
 
-    /*  Now look at how he finished and how far he got.  MAXDIE and
+    /*  Now look at how he finished and how far he got.  NDEATHS and
      *  game.numdie tell us how well he survived.  game.dflag will tell us
      *  if he ever got suitably deep into the cave.  game.closng still